import ccard
from setuptools import setup, find_packages


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CONTRIBUTING.rst') as contributing_file:
    contributing = contributing_file.read()


setup(
    name=ccard.__name__,
    ccard=ccard.__title__,
    version=ccard.__version__,
    author=ccard.__author__,
    author_email=ccard.__email__,
    url=ccard.__link__,
    description=ccard.__info__,
    long_description='\n\n'.join((
        readme,
        contributing,
    )),
    license=ccard.__license__,
    packages=find_packages(),
    package_data={'ccard': ['dist.*']},
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'ccard = ccard.main:main',
        ],
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    test_suite='test_ccard',
)



from __future__ import unicode_literals
from os.path import abspath, join, dirname
import random


__name__ = 'ccard'
__title__ = 'ccard'
__version__ = '0.1.5'
__author__ = 'David Samir'
__email__ = 'dsamir@davidsamir.com'
__link__ = 'https://github.com/davidsamir/credit-card-generator/'
__info__ = 'credit card generator'
__email__ = 'dsamir@davidsamir.com'
__license__ = 'MIT'


full_path = lambda filename: abspath(join(dirname(__file__), filename))


FILES = {
    'visa': full_path('visa'),
    'discover': full_path('discover'),
    'mastercard': full_path('mastercard'),
    'americanexpress': full_path('americanexpress'),
}


def get_number(filename):
    selected = random.random() * 30000
    with open(filename) as name_file:
        for index,line in enumerate(name_file):
            if index > selected:
                return int(line)
    return ''  # Return empty string if file is empty

def visa():
    return get_number(FILES['visa'])

def discover():
    return get_number(FILES['discover'])

def mastercard():
    return get_number(FILES['mastercard'])

def americanexpress():
    return get_number(FILES['americanexpress'])